@@ -16,7 +16,7 @@ pub type Response = cosmwasm_std::Response<StargazeMsgWrapper>;
 pub type SubMsg = cosmwasm_std::SubMsg<StargazeMsgWrapper>;
 pub type CosmosMsg = cosmwasm_std::CosmosMsg<StargazeMsgWrapper>;
 
-pub use fees::{burn_and_distribute_fee, FeeError};
+pub use fees::{checked_fair_burn, fair_burn, FeeError};
 pub use query::StargazeQuery;
 pub use route::StargazeRoute;
 
